/*
 * jSite2 - IdGenerator.java -
 * Copyright © 2008 David Roden
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package net.pterodactylus.jsite.util;

import java.util.Random;

/**
 * A generator for internal IDs.
 *
 * @author David ‘Bombe’ Roden &lt;bombe@freenetproject.org&gt;
 */
public class IdGenerator {

	/** The default length of IDs (in bytes before conversion to a string). */
	public static final int DEFAULT_LENGTH = 20;

	/** The RNG used to created IDs. */
	private static Random random = new Random();

	/**
	 * Generates a new random ID, consisting of {@link #DEFAULT_LENGTH} random
	 * bytes.
	 *
	 * @return The new ID
	 */
	public static byte[] generateId() {
		return generateId(DEFAULT_LENGTH);
	}

	/**
	 * Generates a new random ID, consisting of <code>length</code> random
	 * bytes.
	 *
	 * @param length
	 *            The length of the ID in bytes before conversion to a string
	 * @return The new ID
	 */
	public static byte[] generateId(int length) {
		byte[] idBytes = new byte[length];
		random.nextBytes(idBytes);
		return idBytes;
	}

}
